@@ -14,7 +14,10 @@ MEDIA_PATH = urlparse(settings.MEDIA_URL).path[1:]
 urlpatterns = patterns('',
                        #    url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
                        (r'^login/$', 'django.contrib.auth.views.login', {'template_name': 'login.html'}),
+                       (r'^logcreate/$', 'pythonnest.views.create_user', {'template_name': 'create_user.html'}),
                        (r'^logout/$', 'django.contrib.auth.views.logout', {'next_page': '/'}),
+                       (r'^logchange/$', 'django.contrib.auth.views.password_change',
+                        {'template_name': 'password_change.html', 'post_change_redirect': '/'}),
                        url(r'^admin/', include(admin.site.urls)),
                        (r'^jsi18n/$', 'django.views.i18n.javascript_catalog',
                         {'packages': ('pythonnest', 'django.contrib.admin', ), }),
